<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\AcademicYear;
use App\Historique;

class AcademicyearController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all academicyears and pass it to the view
        $academicyears = AcademicYear::all();

        return view('academicyears.index')->with('academicyears', $academicyears);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('academicyears.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required',
        ]);

        $academicyear = new AcademicYear();
        $academicyear->title = $request->input('title');
        $academicyear->formal_reentry = $request->input('formal_reentry');
        $academicyear->effective_reentry = $request->input('effective_reentry');
        $academicyear->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'AcademicYear';
        $historique->user_id = auth()->user()->id;

        $academicyear->save();
        $historique->save();

        //Redirect to the grades.index view and display message
        return redirect()->route('academicyears.index')
            ->with('success',
             'Nouvelle Année académique ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $academicyear = AcademicYear::findOrFail($id);

        return view('academicyears.edit', compact('academicyear')); //pass academicyear data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $academicyear = AcademicYear::findOrFail($id);

        $this->validate($request, [
            'title' => 'required',
        ]);

        $academicyear->title = $request->input('title');
        $academicyear->formal_reentry = $request->input('formal_reentry');
        $academicyear->effective_reentry = $request->input('effective_reentry');
        $academicyear->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'AcademicYear';
        $historique->user_id = auth()->user()->id;

        $academicyear->save();
        $historique->save();

        //Redirect to the grades.index view and display message
        return redirect()->route('academicyears.index')
            ->with('success',
             'Année académique édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $academicyear = AcademicYear::findOrFail($id);

        $academicyear->delete();

        return redirect()->route('academicyears.index')
            ->with('success',
             'Année académique supprimé avec succès.');
    }
}
