<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Course;
use App\Grade;
use App\Professor;
use App\Historique;
use App\Exam;
use App\TypeExam;
use App\AcademicYear;

class ExamController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all exams  and pass it to the view
        $exams = Exam::all();

        return view('exams.index')->with('exams', $exams);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $academicyears = AcademicYear::pluck('title', 'id');

        $typeexams = TypeExam::pluck('title', 'id');

        $courses = Course::pluck('course_title', 'id');

        return view('exams.create', compact('academicyears','typeexams','courses'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'date_exam' => 'required',
        ]);

        $exam = new Exam();
        $exam->typeexam_id = $request->input('typeexam_id');

        $typeexam = TypeExam::findOrFail($exam->typeexam_id);

        $exam->typeexam_title = $typeexam->title;

        $exam->academicyear_id = $request->input('academicyear_id');

        $academicyear = AcademicYear::findOrFail($exam->academicyear_id);

        $exam->academicyear_title = $academicyear->title;

        $exam->course_id = $request->input('course_id');

        $course = Course::findOrFail($exam->course_id);

        $exam->course_code = $course->course_code;

        $exam->grade_id = $course->grade_id;

        $exam->grade_title = $course->grade_title;

        $exam->course_title = $course->course_title;

        $exam->course_coefficient = $course->coefficient;

        $exam->professor_id =$course->professor_id;

        $professor = Professor::findOrFail($exam->professor_id);

        $exam->professor_name = $professor->name;
        $exam->professor_firstname = $professor->firstname;
        $exam->professor_email = $professor->email;
        $exam->professor_phone = $professor->phone_number;
        $exam->professor_address = $professor->address;
        $exam->professor_profession = $professor->profession ;

        $exam->notation = $request->input('notation');
        $exam->comment = $request->input('comment');
        $exam->period= $request->input('period');
        $exam->date_exam = $request->input('date_exam');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Exam';
        $historique->user_id = auth()->user()->id;

        $exam->save();
        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('exams.index')
            ->with('success',
             'Nouvel Examen ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $courses = Course::pluck('course_title', 'id');

        $typeexams = TypeExam::pluck('title', 'id');

        $academicyears = AcademicYear::pluck('title', 'id');

        $exam = Exam::findOrFail($id);

        return view('exams.edit', compact('exam', 'typeexams', 'academicyears', 'courses'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $exam = Exam::findOrFail($id);

        $this->validate($request, [
            'date_exam' => 'required',
        ]);

        $exam->typeexam_id = $request->input('typeexam_id');

        $typeexam = TypeExam::findOrFail($exam->typeexam_id);

        $exam->typeexam_title = $typeexam->title;

        $exam->academicyear_id = $request->input('academicyear_id');

        $academicyear = AcademicYear::findOrFail($exam->academicyear_id);

        $exam->academicyear_title = $academicyear->title;

        $exam->course_id = $request->input('course_id');

        $course = Course::findOrFail($exam->course_id);

        $exam->course_code = $course->course_code;

        $exam->course_title = $course->course_title;
        $exam->course_coefficient = $course->coefficient;

        $exam->grade_id = $course->grade_id;

        $exam->grade_title = $course->grade_title;

        $exam->professor_id =$course->professor_id;

        $professor = Professor::findOrFail($exam->professor_id);

        $exam->professor_name = $professor->name;
        $exam->professor_firstname = $professor->firstname;
        $exam->professor_email = $professor->email;
        $exam->professor_phone = $professor->phone_number;
        $exam->professor_address = $professor->address;
        $exam->professor_profession = $professor->profession ;
        
        $exam->notation = $request->input('notation');
        $exam->comment = $request->input('comment');
        $exam->period= $request->input('period');
        $exam->date_exam = $request->input('date_exam');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Exam';
        $historique->user_id = auth()->user()->id;

        $exam->save();
        $historique->save();

        //Redirect to the classes.index view and display message
        return redirect()->route('exams.index')
            ->with('success',
             'Nouvel Examen ajouté avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $exam = Exam::findOrFail($id);

        $exam->delete();

        return redirect()->route('exams.index')
            ->with('success',
             'Examen supprimé avec succès.');
    }
}
