<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;

use App\Grade;
use App\Historique;

class GradeController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all grades  and pass it to the view
        $grades = Grade::all();

        return view('grades.index')->with('grades', $grades);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('grades.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required',
        ]);

        $grade = new Grade();
        $grade->title = $request->input('title');
        $grade->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Grade';
        $historique->user_id = auth()->user()->id;

        $grade->save();
        $historique->save();

        //Redirect to the grades.index view and display message
        return redirect()->route('grades.index')
            ->with('success',
             'Nouveau Niveau ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $grade = Grade::findOrFail($id);

        return view('grades.edit', compact('grade')); //pass grade data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $grade = Grade::findOrFail($id);

        $this->validate($request, [
            'title' => 'required',
        ]);

        $grade->title = $request->input('title');
        $grade->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Grade';
        $historique->user_id = auth()->user()->id;

        $grade->save();
        $historique->save();

        //Redirect to the grades.index view and display message
        return redirect()->route('grades.index')
            ->with('success',
             'Niveau édité avec succès.');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $grade = Grade::findOrFail($id);

        $grade->delete();

        return redirect()->route('grades.index')
            ->with('success',
             'Niveau supprimé avec succès.');
    }
}
