<?php

namespace App\Http\Controllers;

use App\Historique;
use App\InscriptionFee;
use App\Student;
use App\StudentParent;
use App\Typefee;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Carbon\Carbon;

class InscriptionFeeController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all inscriptionfees  and pass it to the view
        $inscriptionfees = InscriptionFee::all();

        return view('inscriptionfees.index')->with('inscriptionfees', $inscriptionfees);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $fee  = Typefee::findOrFail(1);
        $price = $fee->fee_amount;
        return view('inscriptionfees.create', compact('price'));
    }

    public function search(Request $request)
    {
        // check if ajax request is coming or not
        if($request->ajax()) {
            $query = $request->get('student');
            // select country name from database
            $data = DB::table('students')
                            ->where('name', 'like', $query.'%')
                            ->orWhere('firstname', 'like', $query.'%')
                            ->get();
            // declare an empty array for output
            $output = '';
            // if searched countries count is larager than zero
            if (count($data) > 0) {
                // concatenate output to the array
                $output = '<ul class="list-group" style="display: block; position: relative; z-index: 1">';
                // loop through the result array
                foreach ($data as $row){
                    // concatenate output to the array
                    $output .= '<li class="list-group-item" data-id="'.$row->id.'">'.$row->name.' '.$row->firstname.'</li>';
                }
                // end of output
                $output .= '</ul>';
            }
            else {
                // if there's no matching results according to the input
                $output .= '<li class="list-group-item">'.'Pas d\'élève trouvé'.'</li>';
            }
            // return output result array
            return $output;
        }
    }
    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'student_id' => 'required',
            'amount_paid' => 'required',
        ]);

        $fee = new InscriptionFee();

        $fee->typefee_id = 1;
        $fee->typefee_title = "Frais d'inscription";
        $fee->amount_Topay = $request->input('amount_Topay');
        $fee->amount_paid = $request->input('amount_paid');
        $fee->left_pay = 0;
        $fee->date = $request->input('date');
        $fee->status = $request->input('status');
        $fee->student_id = $request->input('student_id');

        $student = Student::findOrFail($fee->student_id);
        $fee->student_name = $student->name;
        $fee->student_firstname = $student->firstname;
        $fee->student_email = $student->email;
        $fee->student_gender = $student->gender;
        $fee->student_phone = $student->phone_number;
        $fee->student_address = $student->address;
        $fee->student_userId = $student->user_id;
        $fee->grade_id = $student->grade_id;
        $fee->grade_title = $student->grade_title;
        $fee->classe_id = $student->classe_id;
        $fee->classe_code = $student->classe_code;
        $fee->classe_name = $student->classe_name;

        $parent = StudentParent::findOrFail($student->parent_id);
        $fee->parent_name = $parent->name;
        $fee->parent_firstname = $parent->firstname;
        $fee->parent_email = $parent->email;
        $fee->parent_phone = $parent->phone_number;
        $fee->parent_address = $parent->address;
        $fee->parent_userId = $parent->user_id;
        $fee->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'InscriptionFee';
        $historique->user_id = auth()->user()->id;

        $fee->save();
        $historique->save();

        //Redirect to the inscriptionfees.index view and display message
        return redirect()->route('inscriptionfees.index')
            ->with('success',
             'Nouveau paiement d\'inscription enregistré avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $inscriptionfee = InscriptionFee::findOrFail($id);

        return view('inscriptionfees.show', compact('inscriptionfee')); //pass $inscriptionfee data to view
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $inscriptionfee = InscriptionFee::findOrFail($id);

        $fee  = Typefee::findOrFail(1);

        $price = $fee->fee_amount;

        return view('inscriptionfees.edit', compact('inscriptionfee', 'price')); //pass $inscriptionfee data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $fee = InscriptionFee::findOrFail($id);

        $this->validate($request, [
            'student_id' => 'required',
            'amount_paid' => 'required',
        ]);

        $fee->typefee_id = 1;
        $fee->typefee_title = "Frais d'inscription";
        $fee->amount_Topay = $request->input('amount_Topay');
        $fee->amount_paid = $request->input('amount_paid');
        $fee->left_pay = 0;
        $fee->date = $request->input('date');
        $fee->status = $request->input('status');
        $fee->student_id = $request->input('student_id');

        $student = Student::findOrFail($fee->student_id);
        $fee->student_name = $student->name;
        $fee->student_firstname = $student->firstname;
        $fee->student_email = $student->email;
        $fee->student_gender = $student->gender;
        $fee->student_phone = $student->phone_number;
        $fee->student_address = $student->address;
        $fee->student_userId = $student->user_id;
        $fee->grade_id = $student->grade_id;
        $fee->grade_title = $student->grade_title;
        $fee->classe_id = $student->classe_id;
        $fee->classe_code = $student->classe_code;
        $fee->classe_name = $student->classe_name;

        $parent = StudentParent::findOrFail($student->parent_id);
        $fee->parent_name = $parent->name;
        $fee->parent_firstname = $parent->firstname;
        $fee->parent_email = $parent->email;
        $fee->parent_phone = $parent->phone_number;
        $fee->parent_address = $parent->address;
        $fee->parent_userId = $parent->user_id;
        $fee->user_id = auth()->user()->id;

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'InscriptionFee';
        $historique->user_id = auth()->user()->id;

        $fee->save();
        $historique->save();

        //Redirect to the inscriptionfees.index view and display message
        return redirect()->route('inscriptionfees.index')
            ->with('success',
             'Paiement d\'inscription mis à jour avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $inscrptionfee = InscriptionFee::findOrFail($id);

        $inscrptionfee->delete();

        return redirect()->route('inscrptionfees.index')
            ->with('success',
             'Frais d\'inscription supprimé avec succès.');
    }
}
