<?php

namespace App\Http\Controllers;

use App\Historique;
use App\Student;
use App\StudentParent;
use App\User;
use Illuminate\Http\Request;

class ParentController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all parents  and pass it to the view
        $parents = StudentParent::all();

        return view('parents.index')->with('parents', $parents);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $students = Student::all();

        return view('parents.create', compact('students'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6|confirmed',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/cover_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $parent= new StudentParent();
        $parent->name = $request->input('name');
        $parent->firstname = $request->input('firstname');
        $parent->email = $request->input('email');
        $parent->gender = $request->input('gender');
        $parent->profile_picture = $fileNameToStore;
        $parent->phone_number = $request->input('phone_number');
        $parent->address = $request->input('address');
        $parent->birth_date = $request->input('birth_date');
        $parent->place_birth = $request->input('place_birth');
        $parent->marital_status = $request->input('marital_status');
        $parent->nationality = $request->input('nationality');
        $parent->profession = $request->input('profession');
        $parent->age = $request->input('age');
        $parent->create_user_id = auth()->user()->id;

        $user = new User();
        $user->name = $request->input('name');
        $user->firstname = $request->input('firstname');
        $user->email = $request->input('email');
        $user->password = $request->input('password');
        $user->profile_picture = $fileNameToStore;
        $user->phone_number = $request->input('phone_number');
        $user->address = $request->input('address');
        $user->role_id = 3;


        $parent->save();
        $user->save();
    

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'User/Professor';
        $historique->user_id = auth()->user()->id;

        $parent = StudentParent::findOrFail($parent->id);
        $parent->user_id = $user->id;

        $parent->save();
        $historique->save();

        //Redirect to the professors.index view and display message
        return redirect()->route('parents.index')
            ->with('success',
             'Nouveau Parent d\'élève ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $parent = StudentParent::findOrFail($id);

        return view('parents.show', compact('parent')); //pass $parent data to view
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $parent = StudentParent::findOrFail($id);

        return view('parents.edit', compact('parent')); //pass $parent data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $parent = StudentParent::findOrFail($id);

        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:professors,email,'.$id,
            'password' => 'required|min:6|confirmed',
            'phone_number' => 'required',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/cover_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $parent->name = $request->input('name');
        $parent->firstname = $request->input('firstname');
        $parent->email = $request->input('email');
        $parent->gender = $request->input('gender');
        if ($request->hasfile('profile_picture')) {
            $parent->profile_picture = $fileNameToStore;
        }
        $parent->phone = $request->input('phone_number');
        $parent->address = $request->input('address');
        $parent->birth_date = $request->input('birth_date');
        $parent->place_birth = $request->input('place_birth');
        $parent->marital_status = $request->input('marital_status');
        $parent->nationality = $request->input('nationality');
        $parent->profession = $request->input('profession');
        $parent->age = $request->input('age');
        $parent->create_user_id = auth()->user()->id;
        
        $user = User::findOrFail($parent->user_id);

        $user->name = $request->input('name');
        $user->firstname = $request->input('firstname');
        $user->email = $request->input('email');
        $user->password = $request->input('password');
        $user->phone_number = $request->input('phone_number');
        $user->address = $request->input('address');
        if ($request->hasfile('profile_picture')) {
            $user->profile_picture = $fileNameToStore;
        }
        
        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'User/StudentParent';
        $historique->user_id = auth()->user()->id;
        
        $parent->save();
        $user->save();
		$historique->save();

        return redirect()->route('parents.index')
            ->with('success',
             'Parent d\'élève '.$parent->name.' edité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $parent = StudentParent::findOrFail($id);

        $user = User::findOrFail($parent->user_id);

        if ($user->profile_picture != 'noimage.jpg') {
            Storage::delete('public/cover_images/'.$user->profile_picture);
        }

        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'User/StudentParent';
        $historique->user_id = auth()->user()->id;

        $user->delete();
        $parent->delete();
        $historique->save();

        return redirect()->route('parents.index')
            ->with('success',
             'Parent d\'élève supprimé avec succès.');
    }
}
