<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\User;
use App\Student;
use App\Historique;
use Carbon\Carbon;

class StudentController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all students and pass it to the view
        $students = Student::all();

        return view('students.index')->with('students', $students);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('students.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6|confirmed',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/cover_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $student= new Student();
        $student->name = $request->input('name');
        $student->firstname = $request->input('firstname');
        $student->email = $request->input('email');
        $student->gender = $request->input('gender');
        $student->profile_picture = $fileNameToStore;
        $student->phone_number = $request->input('phone_number');
        $student->address = $request->input('address');
        $student->birth_date = $request->input('birth_date');
        $student->place_birth = $request->input('place_birth');
        $student->marital_status = $request->input('marital_status');
        $student->nationality = $request->input('nationality');

        $dt = Carbon::now();
        Carbon::parse($dt);
        $year2 = intval($dt->year);

        $tmp= Carbon::parse($student->birth_date);
        $year1 = intval($tmp->year);

        $age = $year2 -$year1;
        $student->age = $age;
        $student->create_user_id = auth()->user()->id;

        $user = new User();
        $user->name = $request->input('name');
        $user->firstname = $request->input('firstname');
        $user->email = $request->input('email');
        $user->password = $request->input('password');
        $user->profile_picture = $fileNameToStore;
        $user->phone_number = $request->input('phone_number');
        $user->address = $request->input('address');
        $user->role_id = 1;


        $student->save();
        $user->save();

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'User/Student';
        $historique->user_id = auth()->user()->id;

        $student= Student::findOrFail($student->id);
        $student->user_id = $user->id;

        $student->save();
        $historique->save();

        //Redirect to the students.index view and display message
        return redirect()->route('students.index')
            ->with('success',
             'Nouveau Elève ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $student = Student::findOrFail($id); 

        return view('students.edit', compact('student')); //pass student data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $student = Student::findOrFail($id); 

        //Validate name, email and password fields
        $this->validate($request, [
            'name' => 'required|max:120',
            'firstname' => 'required|max:120',
            'email' => 'required|email|unique:students,email,'.$id,
            'password' => 'required|min:6|confirmed',
            'address' => 'required',
            'profile_picture' => 'image|nullable',
        ]);

        if ($request->hasfile('profile_picture')) {
            // Get filename with the extension
            $fileNameWithExt = $request->file('profile_picture')->getClientOriginalName();

            // Get just filename
            $filename = pathinfo($fileNameWithExt, PATHINFO_FILENAME);

            // Get just ext
            $extension = $request->file('profile_picture')->getClientOriginalExtension();

            // Filename to store
            $fileNameToStore = $filename.'_'.time().'.'.$extension;

            // Upload Image
            $path = $request->file('profile_picture')->storeAs('public/cover_images', $fileNameToStore);
        } else {
            $fileNameToStore = 'noimage.jpg';
        }

        $student->name = $request->input('name');
        $student->firstname = $request->input('firstname');
        $student->email = $request->input('email');
        $student->gender = $request->input('gender');
        if ($request->hasfile('profile_picture')) {
            $student->profile_picture = $fileNameToStore;
        }
        $student->phone_number = $request->input('phone_number');
        $student->address = $request->input('address');
        $student->birth_date = $request->input('birth_date');
        $student->place_birth = $request->input('place_birth');
        $student->marital_status = $request->input('marital_status');
        $student->nationality = $request->input('nationality');

        $dt = Carbon::now();
        Carbon::parse($dt);
        $year2 = intval($dt->year);

        $tmp = Carbon::parse($student->birth_date);
        $year1 = intval($tmp->year);

        $age = $year2 -$year1;
        $student->age = $age;
        $student->create_user_id = auth()->user()->id;

        $user = User::findOrFail($student->user_id);
        $user->name = $request->input('name');
        $user->firstname = $request->input('firstname');
        $user->email = $request->input('email');
        $user->password = $request->input('password');
        if ($request->hasfile('profile_picture')) {
            $user->profile_picture = $fileNameToStore;
        }
        $user->phone_number = $request->input('phone_number');
        $user->address = $request->input('address');


        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'User/Student';
        $historique->user_id = auth()->user()->id;

        $student->save();
        $user->save();
        $historique->save();

        //Redirect to the students.index view and display message
        return redirect()->route('students.index')
            ->with('success',
             'Elève édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $student = Student::findOrFail($id); 

        $user = User::findOrFail($student->user_id);

        if ($user->profile_picture != 'noimage.jpg') {
            Storage::delete('public/cover_images/'.$user->profile_picture);
        }

        $historique = new Historique();
        $historique->action = 'Delete';
        $historique->table = 'User/Student';
        $historique->user_id = auth()->user()->id;

        $user->delete();
        $student->delete();
        $historique->save();

        return redirect()->route('students.index')
            ->with('success',
             'Elève supprimé avec succès.');
    }
}
