<?php

namespace App\Http\Controllers;

use App\Typefee;
use App\Historique;
use Illuminate\Http\Request;

class TypeFeesController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all typefees  and pass it to the view
        $typefees = Typefee::all();

        return view('typefees.index')->with('typefees', $typefees);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('typefees.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required',
            'fee_amount' => 'required',
            'due_date' => 'required'
        ]);

        $typefee = new Typefee();
        $typefee->title = $request->input('title');
        $typefee->description = $request->input('description');
        $typefee->fee_amount = $request->input('fee_amount');
        $typefee->due_date = $request->input('due_date');
        $typefee->status = $request->input('status');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'Typefee';
        $historique->user_id = auth()->user()->id;

        $typefee->save();
        $historique->save();

        //Redirect to the grades.index view and display message
        return redirect()->route('typefees.index')
            ->with('success',
             'Nouveau frais ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $typefee = Typefee::findOrFail($id);

        return view('typefees.edit', compact('typefee')); //pass $typefee data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $typefee = Typefee::findOrFail($id);

        $this->validate($request, [
            'title' => 'required',
            'fee_amount' => 'required',
            'due_date' => 'required'
        ]);

        $typefee->title = $request->input('title');
        $typefee->description = $request->input('description');
        $typefee->fee_amount = $request->input('fee_amount');
        $typefee->due_date = $request->input('due_date');
        $typefee->status = $request->input('status');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'Typefee';
        $historique->user_id = auth()->user()->id;

        $typefee->save();
        $historique->save();

        //Redirect to the typefees.index view and display message
        return redirect()->route('typefees.index')
            ->with('success',
             'Frais édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $typefee = Typefee::findOrFail($id);

        $typefee->delete();

        return redirect()->route('typefees.index')
            ->with('success',
             'Frais supprimé avec succès.');
    }
}
