<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\TypeExam;
use App\Historique;

class TypeexamController extends Controller
{
    public function __construct()
    {
        $this->middleware(['auth', 'isAdmin']); //isAdmin middleware lets only users with a //specific permission permission to access these resources
    }
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //Get all typeexams  and pass it to the view
        $typeexams = TypeExam::all();

        return view('typeexams.index')->with('typeexams', $typeexams);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('typeexams.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'title' => 'required',
        ]);

        $typeexam = new TypeExam();
        $typeexam->title = $request->input('title');
        $typeexam->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Create';
        $historique->table = 'TypeExam';
        $historique->user_id = auth()->user()->id;

        $typeexam->save();
        $historique->save();

        //Redirect to the typeexams.index view and display message
        return redirect()->route('typeexams.index')
            ->with('success',
             'Type Examen ajouté avec succès.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $typeexam = TypeExam::findOrFail($id);

        return view('typeexams.edit', compact('typeexam')); //pass typeexam data to view
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $typeexam = TypeExam::findOrFail($id);

        $this->validate($request, [
            'title' => 'required',
        ]);

        $typeexam->title = $request->input('title');
        $typeexam->description = $request->input('description');

        $historique = new Historique();
        $historique->action = 'Update';
        $historique->table = 'TypeExam';
        $historique->user_id = auth()->user()->id;

        $typeexam->save();
        $historique->save();

        //Redirect to the typeexams.index view and display message
        return redirect()->route('typeexams.index')
            ->with('success',
             'Type Examen édité avec succès.');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $typeexam = TypeExam::findOrFail($id);

        $typeexam->delete();

        return redirect()->route('typeexams.index')
            ->with('success',
             'Type Examen supprimé avec succès.');
    }
}
